#if 0
#elif defined(__arm64__) && __arm64__
// Generated by Apple Swift version 5.9 (swiftlang-5.9.0.128.108 clang-1500.0.40.1)
#ifndef FLYBITSPUSHSDK_SWIFT_H
#define FLYBITSPUSHSDK_SWIFT_H
#pragma clang diagnostic push
#pragma clang diagnostic ignored "-Wgcc-compat"

#if !defined(__has_include)
# define __has_include(x) 0
#endif
#if !defined(__has_attribute)
# define __has_attribute(x) 0
#endif
#if !defined(__has_feature)
# define __has_feature(x) 0
#endif
#if !defined(__has_warning)
# define __has_warning(x) 0
#endif

#if __has_include(<swift/objc-prologue.h>)
# include <swift/objc-prologue.h>
#endif

#pragma clang diagnostic ignored "-Wauto-import"
#if defined(__OBJC__)
#include <Foundation/Foundation.h>
#endif
#if defined(__cplusplus)
#include <cstdint>
#include <cstddef>
#include <cstdbool>
#include <cstring>
#include <stdlib.h>
#include <new>
#include <type_traits>
#else
#include <stdint.h>
#include <stddef.h>
#include <stdbool.h>
#include <string.h>
#endif
#if defined(__cplusplus)
#if defined(__arm64e__) && __has_include(<ptrauth.h>)
# include <ptrauth.h>
#else
#pragma clang diagnostic push
#pragma clang diagnostic ignored "-Wreserved-macro-identifier"
# ifndef __ptrauth_swift_value_witness_function_pointer
#  define __ptrauth_swift_value_witness_function_pointer(x)
# endif
# ifndef __ptrauth_swift_class_method_pointer
#  define __ptrauth_swift_class_method_pointer(x)
# endif
#pragma clang diagnostic pop
#endif
#endif

#if !defined(SWIFT_TYPEDEFS)
# define SWIFT_TYPEDEFS 1
# if __has_include(<uchar.h>)
#  include <uchar.h>
# elif !defined(__cplusplus)
typedef uint_least16_t char16_t;
typedef uint_least32_t char32_t;
# endif
typedef float swift_float2  __attribute__((__ext_vector_type__(2)));
typedef float swift_float3  __attribute__((__ext_vector_type__(3)));
typedef float swift_float4  __attribute__((__ext_vector_type__(4)));
typedef double swift_double2  __attribute__((__ext_vector_type__(2)));
typedef double swift_double3  __attribute__((__ext_vector_type__(3)));
typedef double swift_double4  __attribute__((__ext_vector_type__(4)));
typedef int swift_int2  __attribute__((__ext_vector_type__(2)));
typedef int swift_int3  __attribute__((__ext_vector_type__(3)));
typedef int swift_int4  __attribute__((__ext_vector_type__(4)));
typedef unsigned int swift_uint2  __attribute__((__ext_vector_type__(2)));
typedef unsigned int swift_uint3  __attribute__((__ext_vector_type__(3)));
typedef unsigned int swift_uint4  __attribute__((__ext_vector_type__(4)));
#endif

#if !defined(SWIFT_PASTE)
# define SWIFT_PASTE_HELPER(x, y) x##y
# define SWIFT_PASTE(x, y) SWIFT_PASTE_HELPER(x, y)
#endif
#if !defined(SWIFT_METATYPE)
# define SWIFT_METATYPE(X) Class
#endif
#if !defined(SWIFT_CLASS_PROPERTY)
# if __has_feature(objc_class_property)
#  define SWIFT_CLASS_PROPERTY(...) __VA_ARGS__
# else
#  define SWIFT_CLASS_PROPERTY(...) 
# endif
#endif
#if !defined(SWIFT_RUNTIME_NAME)
# if __has_attribute(objc_runtime_name)
#  define SWIFT_RUNTIME_NAME(X) __attribute__((objc_runtime_name(X)))
# else
#  define SWIFT_RUNTIME_NAME(X) 
# endif
#endif
#if !defined(SWIFT_COMPILE_NAME)
# if __has_attribute(swift_name)
#  define SWIFT_COMPILE_NAME(X) __attribute__((swift_name(X)))
# else
#  define SWIFT_COMPILE_NAME(X) 
# endif
#endif
#if !defined(SWIFT_METHOD_FAMILY)
# if __has_attribute(objc_method_family)
#  define SWIFT_METHOD_FAMILY(X) __attribute__((objc_method_family(X)))
# else
#  define SWIFT_METHOD_FAMILY(X) 
# endif
#endif
#if !defined(SWIFT_NOESCAPE)
# if __has_attribute(noescape)
#  define SWIFT_NOESCAPE __attribute__((noescape))
# else
#  define SWIFT_NOESCAPE 
# endif
#endif
#if !defined(SWIFT_RELEASES_ARGUMENT)
# if __has_attribute(ns_consumed)
#  define SWIFT_RELEASES_ARGUMENT __attribute__((ns_consumed))
# else
#  define SWIFT_RELEASES_ARGUMENT 
# endif
#endif
#if !defined(SWIFT_WARN_UNUSED_RESULT)
# if __has_attribute(warn_unused_result)
#  define SWIFT_WARN_UNUSED_RESULT __attribute__((warn_unused_result))
# else
#  define SWIFT_WARN_UNUSED_RESULT 
# endif
#endif
#if !defined(SWIFT_NORETURN)
# if __has_attribute(noreturn)
#  define SWIFT_NORETURN __attribute__((noreturn))
# else
#  define SWIFT_NORETURN 
# endif
#endif
#if !defined(SWIFT_CLASS_EXTRA)
# define SWIFT_CLASS_EXTRA 
#endif
#if !defined(SWIFT_PROTOCOL_EXTRA)
# define SWIFT_PROTOCOL_EXTRA 
#endif
#if !defined(SWIFT_ENUM_EXTRA)
# define SWIFT_ENUM_EXTRA 
#endif
#if !defined(SWIFT_CLASS)
# if __has_attribute(objc_subclassing_restricted)
#  define SWIFT_CLASS(SWIFT_NAME) SWIFT_RUNTIME_NAME(SWIFT_NAME) __attribute__((objc_subclassing_restricted)) SWIFT_CLASS_EXTRA
#  define SWIFT_CLASS_NAMED(SWIFT_NAME) __attribute__((objc_subclassing_restricted)) SWIFT_COMPILE_NAME(SWIFT_NAME) SWIFT_CLASS_EXTRA
# else
#  define SWIFT_CLASS(SWIFT_NAME) SWIFT_RUNTIME_NAME(SWIFT_NAME) SWIFT_CLASS_EXTRA
#  define SWIFT_CLASS_NAMED(SWIFT_NAME) SWIFT_COMPILE_NAME(SWIFT_NAME) SWIFT_CLASS_EXTRA
# endif
#endif
#if !defined(SWIFT_RESILIENT_CLASS)
# if __has_attribute(objc_class_stub)
#  define SWIFT_RESILIENT_CLASS(SWIFT_NAME) SWIFT_CLASS(SWIFT_NAME) __attribute__((objc_class_stub))
#  define SWIFT_RESILIENT_CLASS_NAMED(SWIFT_NAME) __attribute__((objc_class_stub)) SWIFT_CLASS_NAMED(SWIFT_NAME)
# else
#  define SWIFT_RESILIENT_CLASS(SWIFT_NAME) SWIFT_CLASS(SWIFT_NAME)
#  define SWIFT_RESILIENT_CLASS_NAMED(SWIFT_NAME) SWIFT_CLASS_NAMED(SWIFT_NAME)
# endif
#endif
#if !defined(SWIFT_PROTOCOL)
# define SWIFT_PROTOCOL(SWIFT_NAME) SWIFT_RUNTIME_NAME(SWIFT_NAME) SWIFT_PROTOCOL_EXTRA
# define SWIFT_PROTOCOL_NAMED(SWIFT_NAME) SWIFT_COMPILE_NAME(SWIFT_NAME) SWIFT_PROTOCOL_EXTRA
#endif
#if !defined(SWIFT_EXTENSION)
# define SWIFT_EXTENSION(M) SWIFT_PASTE(M##_Swift_, __LINE__)
#endif
#if !defined(OBJC_DESIGNATED_INITIALIZER)
# if __has_attribute(objc_designated_initializer)
#  define OBJC_DESIGNATED_INITIALIZER __attribute__((objc_designated_initializer))
# else
#  define OBJC_DESIGNATED_INITIALIZER 
# endif
#endif
#if !defined(SWIFT_ENUM_ATTR)
# if __has_attribute(enum_extensibility)
#  define SWIFT_ENUM_ATTR(_extensibility) __attribute__((enum_extensibility(_extensibility)))
# else
#  define SWIFT_ENUM_ATTR(_extensibility) 
# endif
#endif
#if !defined(SWIFT_ENUM)
# define SWIFT_ENUM(_type, _name, _extensibility) enum _name : _type _name; enum SWIFT_ENUM_ATTR(_extensibility) SWIFT_ENUM_EXTRA _name : _type
# if __has_feature(generalized_swift_name)
#  define SWIFT_ENUM_NAMED(_type, _name, SWIFT_NAME, _extensibility) enum _name : _type _name SWIFT_COMPILE_NAME(SWIFT_NAME); enum SWIFT_COMPILE_NAME(SWIFT_NAME) SWIFT_ENUM_ATTR(_extensibility) SWIFT_ENUM_EXTRA _name : _type
# else
#  define SWIFT_ENUM_NAMED(_type, _name, SWIFT_NAME, _extensibility) SWIFT_ENUM(_type, _name, _extensibility)
# endif
#endif
#if !defined(SWIFT_UNAVAILABLE)
# define SWIFT_UNAVAILABLE __attribute__((unavailable))
#endif
#if !defined(SWIFT_UNAVAILABLE_MSG)
# define SWIFT_UNAVAILABLE_MSG(msg) __attribute__((unavailable(msg)))
#endif
#if !defined(SWIFT_AVAILABILITY)
# define SWIFT_AVAILABILITY(plat, ...) __attribute__((availability(plat, __VA_ARGS__)))
#endif
#if !defined(SWIFT_WEAK_IMPORT)
# define SWIFT_WEAK_IMPORT __attribute__((weak_import))
#endif
#if !defined(SWIFT_DEPRECATED)
# define SWIFT_DEPRECATED __attribute__((deprecated))
#endif
#if !defined(SWIFT_DEPRECATED_MSG)
# define SWIFT_DEPRECATED_MSG(...) __attribute__((deprecated(__VA_ARGS__)))
#endif
#if !defined(SWIFT_DEPRECATED_OBJC)
# if __has_feature(attribute_diagnose_if_objc)
#  define SWIFT_DEPRECATED_OBJC(Msg) __attribute__((diagnose_if(1, Msg, "warning")))
# else
#  define SWIFT_DEPRECATED_OBJC(Msg) SWIFT_DEPRECATED_MSG(Msg)
# endif
#endif
#if defined(__OBJC__)
#if !defined(IBSegueAction)
# define IBSegueAction 
#endif
#endif
#if !defined(SWIFT_EXTERN)
# if defined(__cplusplus)
#  define SWIFT_EXTERN extern "C"
# else
#  define SWIFT_EXTERN extern
# endif
#endif
#if !defined(SWIFT_CALL)
# define SWIFT_CALL __attribute__((swiftcall))
#endif
#if !defined(SWIFT_INDIRECT_RESULT)
# define SWIFT_INDIRECT_RESULT __attribute__((swift_indirect_result))
#endif
#if !defined(SWIFT_CONTEXT)
# define SWIFT_CONTEXT __attribute__((swift_context))
#endif
#if !defined(SWIFT_ERROR_RESULT)
# define SWIFT_ERROR_RESULT __attribute__((swift_error_result))
#endif
#if defined(__cplusplus)
# define SWIFT_NOEXCEPT noexcept
#else
# define SWIFT_NOEXCEPT 
#endif
#if !defined(SWIFT_C_INLINE_THUNK)
# if __has_attribute(always_inline)
# if __has_attribute(nodebug)
#  define SWIFT_C_INLINE_THUNK inline __attribute__((always_inline)) __attribute__((nodebug))
# else
#  define SWIFT_C_INLINE_THUNK inline __attribute__((always_inline))
# endif
# else
#  define SWIFT_C_INLINE_THUNK inline
# endif
#endif
#if defined(_WIN32)
#if !defined(SWIFT_IMPORT_STDLIB_SYMBOL)
# define SWIFT_IMPORT_STDLIB_SYMBOL __declspec(dllimport)
#endif
#else
#if !defined(SWIFT_IMPORT_STDLIB_SYMBOL)
# define SWIFT_IMPORT_STDLIB_SYMBOL 
#endif
#endif
#if defined(__OBJC__)
#if __has_feature(objc_modules)
#if __has_warning("-Watimport-in-framework-header")
#pragma clang diagnostic ignored "-Watimport-in-framework-header"
#endif
@import FlybitsSDK;
@import Foundation;
@import ObjectiveC;
@import UIKit;
#endif

#endif
#pragma clang diagnostic ignored "-Wproperty-attribute-mismatch"
#pragma clang diagnostic ignored "-Wduplicate-method-arg"
#if __has_warning("-Wpragma-clang-attribute")
# pragma clang diagnostic ignored "-Wpragma-clang-attribute"
#endif
#pragma clang diagnostic ignored "-Wunknown-pragmas"
#pragma clang diagnostic ignored "-Wnullability"
#pragma clang diagnostic ignored "-Wdollar-in-identifier-extension"

#if __has_attribute(external_source_symbol)
# pragma push_macro("any")
# undef any
# pragma clang attribute push(__attribute__((external_source_symbol(language="Swift", defined_in="FlybitsPushSDK",generated_declaration))), apply_to=any(function,enum,objc_interface,objc_category,objc_protocol))
# pragma pop_macro("any")
#endif

#if defined(__OBJC__)
@class NSString;

/// Controls subscriptions to APNS topics. Convenience functions exist in entities objects.
SWIFT_CLASS("_TtC14FlybitsPushSDK15APNSPreferences")
@interface APNSPreferences : NSObject
/// The object’s description.
@property (nonatomic, readonly, copy) NSString * _Nonnull description;
/// The object’s debugDescription.
@property (nonatomic, readonly, copy) NSString * _Nonnull debugDescription;
- (nonnull instancetype)init SWIFT_UNAVAILABLE;
+ (nonnull instancetype)new SWIFT_UNAVAILABLE_MSG("-init is unavailable");
@end

@class User;
@class NSCoder;

/// The <code>PreferredLanguagesScope</code> class is responsible for managing preferred language for push.
/// When we regist this scope in ScopeOfficer, it will send out preferred languages for push notification to our server.
SWIFT_CLASS("_TtC14FlybitsPushSDK23PreferredLanguagesScope")
@interface PreferredLanguagesScope : NSObject <FlybitsScope>
@property (nonatomic, readonly, copy) NSString * _Nonnull identifier;
/// Gets called on adding the scope
- (void)onStartWithCurrentActiveUserIsOptedIn:(BOOL)currentActiveUserIsOptedIn;
/// Gets called after we connected a user
- (void)onConnectedWithUser:(User * _Nonnull)user;
/// Gets called after we disconnected a user
- (void)onDisconnectedWithJwtToken:(NSString * _Nonnull)jwtToken;
/// Gets called after we destroy an accoung
- (void)onAccountDestroyedWithJwtToken:(NSString * _Nonnull)jwtToken;
/// Gets called after we opt in a user
- (void)onOptIn;
/// Gets called after we opt out a user
- (void)onOptOut;
/// NSCoding decode initializer
- (nullable instancetype)initWithCoder:(NSCoder * _Nonnull)aDecoder;
/// NSCoding encode
- (void)encodeWithCoder:(NSCoder * _Nonnull)aCoder;
- (nonnull instancetype)init OBJC_DESIGNATED_INITIALIZER;
@end

enum PushMessageEntity : NSInteger;

/// A protocol to allow easy subscription and unsubscription from Flybits model objects.
SWIFT_PROTOCOL("_TtP14FlybitsPushSDK16PushConfigurable_")
@protocol PushConfigurable
/// Unique identifier for the message
@property (nonatomic, readonly, copy) NSString * _Nonnull identifier;
/// Push message entity type
@property (nonatomic, readonly) enum PushMessageEntity pushEntityType;
/// Route for the message
@property (nonatomic, readonly, copy) NSString * _Nonnull route;
/// Subscribes the current object to push for the desired push <code>type</code>.
/// \param type The type of notification desired.
///
- (void)subscribeToPush;
/// Unsubscribes the current object to push for the desired push <code>type</code>.
/// \param type The type of notification desired.
///
- (void)unsubscribeFromPush;
@end

enum PushServiceLevel : NSInteger;
@class NSData;

/// A set of configurable properties for the push manager.
/// Currently, the service level and APNS token are supported.
SWIFT_CLASS("_TtC14FlybitsPushSDK17PushConfiguration")
@interface PushConfiguration : NSObject
/// A convenience function for creating a <code>PushConfiguration</code> with a pre-defined <code>PushServiceLevel</code> and APNS token.
/// \param serviceLevel The desired <code>PushServiceLevel</code>.
///
/// \param andAPNSToken The App’s APNS token.
///
///
/// returns:
/// A <code>PushConfiguration</code>.
+ (PushConfiguration * _Nonnull)configurationWithServiceLevel:(enum PushServiceLevel)serviceLevel andAPNSToken:(NSData * _Nullable)apnsToken SWIFT_WARN_UNUSED_RESULT SWIFT_DEPRECATED_MSG("Please use configuration(with serviceLevel: PushServiceLevel) method");
- (nonnull instancetype)init SWIFT_UNAVAILABLE;
+ (nonnull instancetype)new SWIFT_UNAVAILABLE_MSG("-init is unavailable");
@end

@class FlybitsRequest;
@class PushMessage;
@class NSNotification;

/// Manages handling Flybits related push messages.
/// When a <code>PushConfiguration</code> is provided, it will automatically connect, if required. The <code>PushManager</code> requires a user to be logged in before connecting.
SWIFT_CLASS("_TtC14FlybitsPushSDK11PushManager")
@interface PushManager : NSObject
/// Used to pass APNS notifications to the <code>PushManager</code>.
/// \param notification An APNS notification.
///
/// \param fetchCompletionHandler The optional <code>fetchCompletionHandler</code> to call back if async data needs to be retrieved.
///
///
/// returns:
/// <code>true</code> if the content was decoded properly (i.e. a properly formatted SDK push notification), <code>false</code> if the content is not in the proper format (i.e. a push notification not intended for the SDK or a mangled push message).
- (BOOL)receivedNotification:(NSDictionary<NSString *, id> * _Nonnull)notification fetchCompletionHandler:(void (^ _Nullable)(UIBackgroundFetchResult))completionHandler;
/// Retrieves a list of unsubscribed push topics for the connected Flybits user
/// \param completion A block that will return the user’s unsubscribed push topics or an error if the request was unsuccessful
///
///
/// returns:
/// A cancellable <code>FlybitsRequest</code> object
- (FlybitsRequest * _Nonnull)unsubscribedTopicsWithCompletion:(void (^ _Nonnull)(NSArray<NSString *> * _Nullable, NSError * _Nullable))completion;
/// Unsubscribes connected Flybits user to the specified push topic
/// \param topic The push topic that will be unsubscribed from
///
/// \param completion A block that will return the user’s updated unsubscribed push topics or an error if the request was unsuccessful
///
///
/// returns:
/// A cancellable <code>FlybitsRequest</code> object
- (FlybitsRequest * _Nonnull)unsubscribeToTopic:(NSString * _Nonnull)topic completion:(void (^ _Nullable)(NSArray<NSString *> * _Nullable, NSError * _Nullable))completion;
/// Subscribes connected Flybits user to the specified push topic
/// \param topic The push topic that will be subscribed to
///
/// \param completion A block that will return the user’s updated unsubscribed push topics or an error if the request was unsuccessful
///
///
/// returns:
/// A cancellable <code>FlybitsRequest</code> object
- (FlybitsRequest * _Nonnull)subscribeToTopic:(NSString * _Nonnull)topic completion:(void (^ _Nullable)(NSArray<NSString *> * _Nullable, NSError * _Nullable))completion;
/// Method fetch all user’s notifications.
/// \param completion Callback with either an array of notifications or an error
///
/// \param pushMessages Array of push messages or nil
///
/// \param error Contains the networking error or nil
///
///
/// returns:
/// A cancellable reqeust
- (FlybitsRequest * _Nonnull)userNotificationsWithCompletion:(void (^ _Nonnull)(NSArray<PushMessage *> * _Nullable, NSError * _Nullable))completion;
/// Notifications default sending content in English (<em>en</em>) but that’s not necessarily the default language
/// of the device. This API will enable the push content to be localized to the extent the creator of the push
/// message supports their language code.
/// note:
/// This method only needs to be called one time if the default language needs to change. It will be persisted in Flybits for future executions of the app.
/// Call this method again if it changes.
/// warning:
/// This method doesn’t validate <em>code</em> against any list of valid language codes.
/// \param code The language code the user would prefer their push notifications be displayed as
///
/// \param completion Callback of the success / failure of the network call
///
/// \param error Contains the reason why the attempt to set the language code failed, otherwise nil.
///
///
/// returns:
/// A cancellable request
+ (FlybitsRequest * _Nonnull)setPreferredLanguageWithCode:(NSString * _Nonnull)code completion:(void (^ _Nonnull)(NSError * _Nullable))completion;
/// To support multiple languages supports for notification for user.
/// \param codes list of language code. Order does matter.
///
/// \param completion Callback of success / failure of the network call
///
+ (FlybitsRequest * _Nonnull)setPreferredLanguagesWithCodes:(NSArray<NSString *> * _Nonnull)codes completion:(void (^ _Nonnull)(NSError * _Nullable))completion;
/// Determines if the notification passed in is from Flybits.
/// <ul>
///   <li>
///     Parameter:
///     <ul>
///       <li>
///         notification: A dictionary of the root of a notification’s payload.
///       </li>
///     </ul>
///   </li>
/// </ul>
- (BOOL)isFlybitsNotification:(NSDictionary<NSString *, id> * _Nonnull)notification SWIFT_WARN_UNUSED_RESULT;
/// Determines if the notification passed in is silent.
/// \param notification A dictionary of the root of a notification’s payload.
///
- (BOOL)isSilentNotification:(NSNotification * _Nonnull)notification SWIFT_WARN_UNUSED_RESULT;
- (nonnull instancetype)init SWIFT_UNAVAILABLE;
+ (nonnull instancetype)new SWIFT_UNAVAILABLE_MSG("-init is unavailable");
@end


/// A class containing a number of constants used with PushManager.
SWIFT_CLASS("_TtC14FlybitsPushSDK20PushManagerConstants")
@interface PushManagerConstants : NSObject
- (nonnull instancetype)init OBJC_DESIGNATED_INITIALIZER;
@end


/// A list of error codes that can be issued by the <code>PushManager</code>.
SWIFT_CLASS("_TtC14FlybitsPushSDK25PushManagerErrorConstants")
@interface PushManagerErrorConstants : NSObject
- (nonnull instancetype)init OBJC_DESIGNATED_INITIALIZER;
@end


/// PushMessage defines notification/push message related information such as alert, title, body, etc. for the notification
SWIFT_CLASS("_TtC14FlybitsPushSDK11PushMessage")
@interface PushMessage : NSObject
/// Unique identifier for the message
@property (nonatomic, readonly, copy) NSString * _Nonnull identifier;
/// Description string
@property (nonatomic, readonly, copy) NSString * _Nonnull description;
/// Debug description string
@property (nonatomic, readonly, copy) NSString * _Nonnull debugDescription;
- (nonnull instancetype)init SWIFT_UNAVAILABLE;
+ (nonnull instancetype)new SWIFT_UNAVAILABLE_MSG("-init is unavailable");
@end

/// Push message action types
typedef SWIFT_ENUM(NSInteger, PushMessageAction, open) {
/// custom
  PushMessageActionCustom = 0,
/// content
  PushMessageActionContent = 1,
/// website
  PushMessageActionWebsite = 2,
/// Generated by Concierge for local notifications if downloading content before displaying
/// notification.
/// openConcierge
  PushMessageActionOpenConciergeNotifications = 3,
  PushMessageActionOpenContent = 4,
  PushMessageActionOpenContentAndOpenConciergeNotifications = 5,
/// CRUD minus the “Read” - CUD operations
  PushMessageActionCreated = 6,
/// CRUD minus the “Read” - CUD operations
  PushMessageActionUpdated = 7,
/// CRUD minus the “Read” - CUD operations
  PushMessageActionDeleted = 8,
  PushMessageActionChanged = 9,
};

/// Push message category types
typedef SWIFT_ENUM(NSInteger, PushMessageCategory, open) {
/// custom
  PushMessageCategoryCustom = 0,
/// core
  PushMessageCategoryCore = 1,
/// context
  PushMessageCategoryContext = 2,
/// kernel
  PushMessageCategoryKernel = 3,
/// push
  PushMessageCategoryPush = 4,
};

/// Push message entity types
typedef SWIFT_ENUM(NSInteger, PushMessageEntity, open) {
/// any other including basic push message alert
  PushMessageEntityCustom = 0,
/// kernel
  PushMessageEntityGroup = 1,
/// kernel
  PushMessageEntityExperience = 2,
/// kernel
  PushMessageEntityContent = 3,
/// kernel
  PushMessageEntityContentData = 4,
/// kernel
  PushMessageEntityRelevantContent = 5,
/// context
  PushMessageEntityRule = 6,
};


SWIFT_CLASS("_TtC14FlybitsPushSDK11PushPayload")
@interface PushPayload : NSObject
- (nonnull instancetype)init SWIFT_UNAVAILABLE;
+ (nonnull instancetype)new SWIFT_UNAVAILABLE_MSG("-init is unavailable");
@end


SWIFT_CLASS("_TtC14FlybitsPushSDK18PushPayloadContent")
@interface PushPayloadContent : PushPayload
@end


SWIFT_CLASS("_TtC14FlybitsPushSDK37PushPayloadOpenConciergeNotifications")
@interface PushPayloadOpenConciergeNotifications : PushPayloadContent
@end


SWIFT_CLASS("_TtC14FlybitsPushSDK22PushPayloadOpenContent")
@interface PushPayloadOpenContent : PushPayloadContent
@end


SWIFT_CLASS("_TtC14FlybitsPushSDK34PushPayloadOpenContentAndConcierge")
@interface PushPayloadOpenContentAndConcierge : PushPayloadContent
@end


SWIFT_CLASS("_TtC14FlybitsPushSDK18PushPayloadWebsite")
@interface PushPayloadWebsite : PushPayload
@end


/// Used for filtering the results of the <code>PushRequest.NotificationHistory</code> API.
SWIFT_CLASS("_TtC14FlybitsPushSDK9PushQuery")
@interface PushQuery : NSObject
- (nonnull instancetype)init SWIFT_UNAVAILABLE;
+ (nonnull instancetype)new SWIFT_UNAVAILABLE_MSG("-init is unavailable");
@end


/// The <code>PushScope</code> class is responsible for managing Push and Notifications options when initializing
/// the Push SDK. This is a primary step to configure and define attributes that are required for
/// notifications processing.
SWIFT_CLASS("_TtC14FlybitsPushSDK9PushScope")
@interface PushScope : NSObject <FlybitsScope>
@property (nonatomic, readonly, copy) NSString * _Nonnull identifier;
/// Gets called on adding the scope
- (void)onStartWithCurrentActiveUserIsOptedIn:(BOOL)currentActiveUserIsOptedIn;
/// Gets called on removing the scope
- (void)onStop;
/// Gets called on successfully connecting to the IDP
- (void)onConnectedWithUser:(User * _Nonnull)user;
/// Gets called on disconnecting from the IDP
- (void)onDisconnectedWithJwtToken:(NSString * _Nonnull)jwtToken;
/// Gets called when a user account gets destroyed
- (void)onAccountDestroyedWithJwtToken:(NSString * _Nonnull)jwtToken;
/// Gets called when a user account opt In of Flybits
- (void)onOptIn;
/// Gets called when a user account opt out of Flybits
- (void)onOptOut;
/// NSCoding decode initializer
- (nullable instancetype)initWithCoder:(NSCoder * _Nonnull)aDecoder;
/// NSCoding encode
- (void)encodeWithCoder:(NSCoder * _Nonnull)aCoder;
- (nonnull instancetype)init OBJC_DESIGNATED_INITIALIZER;
@end

/// The desired service level
typedef SWIFT_ENUM(NSInteger, PushServiceLevel, open) {
/// No push notifications will be received.
  PushServiceLevelNone = 0,
/// Foreground push notifications will be received via <code>NSNotificationCenter</code>
  PushServiceLevelForeground = 1,
/// Background push notifications will be received via <code>NSNotificationCenter</code>
  PushServiceLevelBackground = 2,
/// Foreground and Background push notifications will be received via <code>NSNotificationCenter</code>
  PushServiceLevelBoth = 3,
};

/// Defines a source for the origin of the <code>PushMessage</code>.
typedef SWIFT_ENUM(NSInteger, PushSource, open) {
/// An Apple Push Notification Service message.
  PushSourceApns = 0,
/// A MQ Telemetry Transport
  PushSourceMqtt = 1,
};


/// The <code>PushTemplate</code> class is used to define all the necessary parameters associated to a
/// push notification that is sent to user’s based on changing contextual values and hence the
/// changing of rule evaluation states.
SWIFT_CLASS("_TtC14FlybitsPushSDK12PushTemplate")
@interface PushTemplate : NSObject
- (nonnull instancetype)init SWIFT_UNAVAILABLE;
+ (nonnull instancetype)new SWIFT_UNAVAILABLE_MSG("-init is unavailable");
@end


/// Push template options that allows to specify maximum number of time to send the message, delay between messages and cooldown time for the push messages
SWIFT_CLASS("_TtC14FlybitsPushSDK19PushTemplateOptions")
@interface PushTemplateOptions : NSObject
- (nonnull instancetype)init SWIFT_UNAVAILABLE;
+ (nonnull instancetype)new SWIFT_UNAVAILABLE_MSG("-init is unavailable");
@end

/// Rule result for evaluations
typedef SWIFT_ENUM(NSInteger, RuleResult, open) {
/// Evaluates to true
  RuleResultTrue = 1,
/// Evaluates to false
  RuleResultFalse = 2,
/// Evaluates to true or false
  RuleResultTrueOrFalse = 3,
};


#endif
#if __has_attribute(external_source_symbol)
# pragma clang attribute pop
#endif
#if defined(__cplusplus)
#endif
#pragma clang diagnostic pop
#endif

#else
#error unsupported Swift architecture
#endif
